********************************************************************************
*COMMAND AID - Bachelor analysis of PIRILS data focused on PC use in class
*Created by Nikolai Eugen Lamøy, Spring 2020
*Intended for personal use in tracking progress and file alterations
********************************************************************************
*ALLREADY CREATED APPENDED DATASETS, using command "append using":
*1 - Containing data from NORWAY, ENGLAND & USA - FOCUS OF BACHELOR
*2 - Containing all available PIRLS data of the 35 countries
********************************************************************************
*
********************************************************************************
*New dummy variables from categorical variables:
********************************************************************************
*Generating dummies for «teacher_age»
*dummy for age UNDER 25
gen tage_u25=0 if teacher_age!=.
replace tage_u25=1 if teacher_age==1
*dummy for age 25-29
gen tage_25_29=0 if teacher_age!=.
replace tage_25_29=1 if teacher_age==2
*dummy for age 30-39
gen tage_30_39=0 if teacher_age!=.
replace tage_30_39=1 if teacher_age==3
*dummy for age 40-49 
gen tage_40_49=0 if teacher_age!=.
replace tage_40_49=1 if teacher_age==4
*dummy for age 50-59 
gen tage_50_59=0 if teacher_age!=.
replace tage_50_59=1 if teacher_age==5
*dummy for age OVER 60 
gen tage_o60=0 if teacher_age!=.
replace tage_o60=1 if teacher_age==6
*Descriptive statistics for 6 constructed dummies from categories in teacher_age
sum tage_u25 tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60
*Verify that all categories are now dummies summarized to 1
gen tage_sum=tage_u25+tage_25_29+tage_30_39+tage_40_49+tage_50_59+tage_o60
sum tage_sum
********************************************************************************
*Generating dummies for «pct_disadv»
*dummy for percent disadvantaged peers UNDER 10
gen pdisad_u10=0 if pct_disadv!=.
replace pdisad_u10=1 if pct_disadv==1
*dummy for percent disadvantaged peers 11-25
gen pdisad_11_25=0 if pct_disadv!=.
replace pdisad_11_25=1 if pct_disadv==2
*dummy for percent disadvantaged peers 26-50
gen pdisad_26_50=0 if pct_disadv!=.
replace pdisad_26_50=1 if pct_disadv==3
*dummy for percent disadvantaged peers OVER 50 
gen pdisad_o50=0 if pct_disadv!=.
replace pdisad_o50=1 if pct_disadv==4
*Descriptive statistics for 4 constructed dummies from categories in pct_disadv
sum pdisad_u10 pdisad_11_25 pdisad_26_50 pdisad_o50
*Verify that all categories are now dummies summarized to 1
gen pdisad_sum=pdisad_u10+pdisad_11_25+pdisad_26_50+pdisad_o50
sum pdisad_sum
********************************************************************************
*Generating dummies for «pct_abroad»
*dummy for percent peers born abroad UNDER 10
gen pabr_u10=0 if pct_abroad!=.
replace pabr_u10=1 if pct_abroad==1
*dummy for percent peers born abroad 11-25
gen pabr_11_25=0 if pct_abroad!=.
replace pabr_11_25=1 if pct_abroad==2
*dummy for percent peers born abroad 26-50
gen pabr_26_50=0 if pct_abroad!=.
replace pabr_26_50=1 if pct_abroad==3
*dummy for percent peers born abroad OVER 50 
gen pabr_o50=0 if pct_abroad!=.
replace pabr_o50=1 if pct_abroad==4
*Descriptive statistics for 4 constructed dummies from categories in pct_abroad
sum pabr_u10 pabr_11_25 pabr_26_50 pabr_o50
*Verify that all categories are now dummies summarized to 1
gen pabr_sum=pabr_u10+pabr_11_25+pabr_26_50+pabr_o50
sum pabr_sum
********************************************************************************
*Generating dummies for «par_edu»
*dummy for parent university education
gen pedu_uni=0 if par_edu!=.
replace pedu_uni=1 if par_edu==1
*dummy for parent post secondary education
gen pedu_post=0 if par_edu!=.
replace pedu_post=1 if par_edu==2
*dummy for parent upper secondary education
gen pedu_upper=0 if par_edu!=.
replace pedu_upper=1 if par_edu==3
*dummy for parent lower secondary education 
gen pedu_lower=0 if par_edu!=.
replace pedu_lower=1 if par_edu==4
*dummy for no parent secondary education 
gen pedu_nosec=0 if par_edu!=.
replace pedu_nosec=1 if par_edu==5
*Descriptive statistics for 5 constructed dummies from categories in par_edu
sum pedu_uni pedu_post pedu_upper pedu_lower pedu_nosec
*Verify that all categories are now dummies summarized to 1
gen pedu_sum=pedu_uni+pedu_post+pedu_upper+pedu_lower+pedu_nosec
sum pedu_sum
********************************************************************************
*Generating dummies for «par_emp»
*dummy for Both parents working Fulltime
gen pemp_full=0 if par_emp!=.
replace pemp_full=1 if par_emp==1
*dummy for Only One parent working fulltime
gen pemp_one=0 if par_emp!=.
replace pemp_one=1 if par_emp==2
*dummy for Both parents working Less than fulltime
gen pemp_less=0 if par_emp!=.
replace pemp_less=1 if par_emp==3
*dummy for Parents Not working 
gen pemp_not=0 if par_emp!=.
replace pemp_not=1 if par_emp==4
*Descriptive statistics for 4 constructed dummies from categories in par_emp
sum pemp_full pemp_one pemp_less pemp_not
*Verify that all categories are now dummies summarized to 1
gen pemp_sum=pemp_full+pemp_one+pemp_less+pemp_not
sum pemp_sum
********************************************************************************
*Generating dummies for «income»
*dummy for Household income measured in USD of UNDER 20K
gen hinc_u20k=0 if income!=.
replace hinc_u20k=1 if income==1
*dummy for Household income measured in USD of 20,000-29,999
gen hinc_20k29=0 if income!=.
replace hinc_20k29=1 if income==2
*dummy for Household income measured in USD of 30,000-39,999
gen hinc_30k39=0 if income!=.
replace hinc_30k39=1 if income==3
*dummy for Household income measured in USD of 40,000-49,999
gen hinc_40k49=0 if income!=.
replace hinc_40k49=1 if income==4
*dummy for Household income measured in USD of 50,000-59,999
gen hinc_50k59=0 if income!=.
replace hinc_50k59=1 if income==5
*dummy for Household income measured in USD of OVER 60K
gen hinc_o60k=0 if income!=.
replace hinc_o60k=1 if income==6
*Descriptive statistics for 6 constructed dummies from categories in income
sum hinc_u20k hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k
*Verify that all categories are now dummies summarized to 1
gen hinc_sum=hinc_u20k+hinc_20k29+hinc_30k39+hinc_40k49+hinc_50k59+hinc_o60k
sum hinc_sum
********************************************************************************
*Generating dummies for «speak_testlang_home»
*dummy for student Speaking testlanuage home Always
gen speakhome_always=0 if speak_testlang_home!=.
replace speakhome_always=1 if speak_testlang_home==1
*dummy for student Speaking testlanuage home Sometimes
gen speakhome_sometimes=0 if speak_testlang_home!=.
replace speakhome_sometimes=1 if speak_testlang_home==2
*dummy for student Speaking testlanuage home Never
gen speakhome_never=0 if speak_testlang_home!=.
replace speakhome_never=1 if speak_testlang_home==3
*Descriptive statistics for 3 constructed dummies from categories in speak_testlang_home
sum speakhome_always speakhome_sometimes speakhome_never
*Verify that all categories are now dummies summarized to 1
gen speakhome_sum=speakhome_always+speakhome_sometimes+speakhome_never
sum speakhome_sum
********************************************************************************
*
********************************************************************************
*Data presentation
********************************************************************************
*presenting countries in dataset by registered country id in PIRLS
tab idcntry
********************************************************************************
*presenting descriptive statistics for DEPENDANT VARIABLE "read" test score
sum read
*presenting a histogram of frequency and test score with labels in norwegian
*black dotted line added to illustrate normal distribution
histogram read, width(5) frequency fcolor(navy) lcolor(dknavy) normal normopts(lcolor(black) lpattern(dash)) ytitle(Frekvens) xtitle(PIRLS test score for leseferdigheter [variablen *read*])
********************************************************************************
*presenting descriptive statistics for VARIABLE OF INTEREST "pc_class" dummy
sum pc_class
tab pc_class
*pie chart
graph pie, over(pc_class) pie(1, color(ltblue)) pie(2, color(navy)) line(lcolor(black))
*Scatter plot between "read" and "pc_class" with simple regression line
*Norwegian labels with added referance lines and legend hidden
twoway (scatter read pc_class) (lfit read pc_class), ytitle(Test score [read]) yline(300 500 700, lcolor(gray%15)) xtitle(Nei                              Skole-PC [dummy variabelen *pc_class*]                     Ja) legend(off)
*descriptive statistics for each dummy values in relation to read*
sum read if pc_class==1
sum read if pc_class==0
********************************************************************************
*Descriptive statistics for CONTROL VARIABLES 
********************************************************************************
*Descriptive statistics for continous control variables
sum teacher_exp clsize
*Scatter plot of each
twoway (scatter read teacher_exp) (lfit read teacher_exp), ytitle(Test score [read]) yline(300 500 700, lcolor(gray%15)) xtitle(Antall år læreren har jobbet i yrket [teacher_exp]) legend(off)
twoway (scatter read clsize) (lfit read clsize), ytitle(Test score [read]) yline(300 500 700, lcolor(gray%15)) xtitle(Klassestørrelse - antall elever i klassen [clsize]) legend(off)
*Distribution tables for categorical variables made into dummies 
tab teacher_age
tab pct_disadv
tab pct_abroad
tab par_edu
tab par_emp
tab income
tab speak_testlang_home
* & original dummy
tab kinderg_att
*Summarization of all control variables, categorical variables made into dummies
sum teacher_exp tage_u25 tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 clsize pdisad_u10 pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_u10 pabr_11_25 pabr_26_50 pabr_o50 pedu_uni pedu_post pedu_upper pedu_lower pedu_nosec pemp_full pemp_one pemp_less pemp_not hinc_u20k hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k speakhome_always speakhome_sometimes speakhome_never kinderg_att
********************************************************************************
*Correlation matrices for the data material
********************************************************************************
*Simple correlation matix for all direct and indirect variables to be included
corr read pc_class teacher_exp tage_u25 tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 clsize pdisad_u10 pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_u10 pabr_11_25 pabr_26_50 pabr_o50 pedu_uni pedu_post pedu_upper pedu_lower pedu_nosec pemp_full pemp_one pemp_less pemp_not hinc_u20k hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k speakhome_always speakhome_sometimes speakhome_never kinderg_att
*Partial, Semipartial w/p-values excluding referance category dummies
*This is done to avoid perfect multicollinearity, chosen referance dummies are:
*tage_u25 pdisad_u10 pabr_u10 pedu_nosec pemp_one hinc_u20k speakhome_always
*In relation to dependant variable:
pcorr read pc_class teacher_exp tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 clsize pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50 pedu_uni pedu_post pedu_upper pedu_lower pemp_full pemp_less pemp_not hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k speakhome_sometimes speakhome_never kinderg_att
*In relation to variable of interest:
pcorr pc_class read teacher_exp tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 clsize pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50 pedu_uni pedu_post pedu_upper pedu_lower pemp_full pemp_less pemp_not hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k speakhome_sometimes speakhome_never kinderg_att
********************************************************************************
*REGRESSION MODELS & RESULTS - DATASET 1: NORWAY, ENGLAND & USA
********************************************************************************
*(1) Only dependant and variable and variable of interest
reg read pc_class
*Predicting and storing residuals for Model 1
predict e_1, residuals
*Histogram of residuals with normal distribution check for hypothesis test validity
histogram e_1, width(5) frequency fcolor(navy) lcolor(dknavy) normal normopts(lcolor(black) lpattern(dash)) ytitle(Frekvens) xtitle(Restledd - Modell 1)
*RESULT: approximatly normally distributed residuals
*
*Doing Breusch-Pagan test for heteroscedasticity in Model 1
*Done by regressing the squared residuals on the explanatory variables of the model
*F-test, p-value 0.05 or less to reject, where null hypothesis is homoscedasticity.
*If significant, the variables are correlated with the error term - heteroscedasticity
gen e2_1=e_1^2
reg e2_1 pc_class
*RESULT: Withhold judgement, cannot reject null hypothesis, p>F = 0.9122
********************************************************************************
*(2) Adding teacher_exp continous control variable
reg read pc_class teacher_exp
*Predicting and storing residuals for Model 2
predict e_2, residuals
*Histogram normal distribution check
histogram e_2, width(5) frequency fcolor(navy) lcolor(dknavy) normal normopts(lcolor(black) lpattern(dash)) ytitle(Frekvens) xtitle(Restledd - Modell 2)
*RESULT: approximatly normally distributed residuals
*
*Doing the Breusch-Pagan test for heteroscedasticity in Model 2
gen e2_2=e_2^2
reg e2_2 pc_class teacher_exp
*RESULT: Withhold judgement, cannot reject null hypothesis, p>F = 0.1806
*
*NOTE:
*The added variable teacher_exp ONLY passes a one side t-test with p-value of 0.05
*Marginal improvement of models predictive capabilities, R-squared
********************************************************************************
*(3) Adding teacher_age categorical control variable, referance: tage_u25
reg read pc_class teacher_exp tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60
*Predicting and storing residuals for Model 3
predict e_3, residuals
*Histogram normal distribution check
histogram e_3, width(5) frequency fcolor(navy) lcolor(dknavy) normal normopts(lcolor(black) lpattern(dash)) ytitle(Frekvens) xtitle(Restledd - Modell 3)
*RESULT: approximatly normally distributed residuals
*
*Doing the Breusch-Pagan test for heteroscedasticity in Model 3
gen e2_3=e_3^2
reg e2_3 pc_class teacher_exp tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60
*RESULT: Rejecting null hypothesis of homoscedasticity, p>F = 0.0061
*Accounting for model heteroscedasticity by using added robust command to regression *This makes use of broader robust (Eicker–Huber–White) standard errors
reg read pc_class teacher_exp tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60, robust
*
*NOTE:
*The dummy variables transformed from categorical variables must be viewed as a whole
*Their common interdependant significans can be determinded by a chow-test/F-test
*Null hypothesis is that test variables are collectively insignificant, p = 0.05
*Robust F-test of added categorical dummies:
reg read pc_class teacher_exp tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60, robust
test tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60
*RESULT: Rejecting null hypothesis of collective insignificans, p>F = 0.0008
*
*NOTE:
*teacher_age now also fails a one-tailed t-test at 95% significans
*Dropping teacher_age as control variable moving forwards
********************************************************************************
*(4) Adding clsize continous control variable
reg read pc_class tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 clsize, robust
*Predicting and storing residuals for Model 4
predict e_4, residuals
*Histogram normal distribution check
histogram e_4, width(5) frequency fcolor(navy) lcolor(dknavy) normal normopts(lcolor(black) lpattern(dash)) ytitle(Frekvens) xtitle(Restledd - Modell 4)
*RESULT: approximatly normally distributed residuals
*NOTE:
*Model shows positive relation of increased class size, over 99% significant?
********************************************************************************
*(5) Adding Categorical Peer Characteristics: pct_disadv & pct_abroad
reg read pc_class clsize tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50, robust
*Predicting and storing residuals for Model 5
predict e_5, residuals
*Histogram normal distribution check
histogram e_5, width(5) frequency fcolor(navy) lcolor(dknavy) normal normopts(lcolor(black) lpattern(dash)) ytitle(Frekvens) xtitle(Restledd - Modell 5)
*RESULT: approximatly normally distributed residuals
*
*Insignificans F-test of all added Peer Characteristics dummies, p = 0.05:
reg read pc_class clsize tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50, robust
test pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50
*RESULT: Rejecting null hypothesis of collective insignificans, p>F = 0.0000
*
*Insignificans F-test of pct_disadv category dummies, p = 0.05:
reg read pc_class clsize tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50, robust
test pdisad_11_25 pdisad_26_50 pdisad_o50
*RESULT: Rejecting null hypothesis of collective insignificans, p>F = 0.0000
*
*Insignificans F-test of pct_disadv category dummies, p = 0.05:
reg read pc_class clsize tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50, robust
test pabr_11_25 pabr_26_50 pabr_o50
*RESULT: Rejecting null hypothesis of collective insignificans, p>F = 0.0000
*NOTE:
*A significant increase in R squared with the added Peer Charachteristics
********************************************************************************
*(6) Adding Family- and student characteristics:
*4 Categorical variables made dummies: par_edu par_emp income speak_testlang_home
*Original dummy: kinderg_att
reg read pc_class tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 clsize pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50 pedu_uni pedu_post pedu_upper pedu_lower pemp_full pemp_less pemp_not hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k speakhome_sometimes speakhome_never kinderg_att, robust
*Predicting and storing residuals for Model 5
predict e_6, residuals
*Histogram normal distribution check
histogram e_6, width(5) frequency fcolor(navy) lcolor(dknavy) normal normopts(lcolor(black) lpattern(dash)) ytitle(Frekvens) xtitle(Restledd - Modell 6)
*RESULT: approximatly normally distributed residuals
*
*NOTE:
*kinderg_att is insignificant even at in one-tailed 95% confidens
*Insignificans F-testing for all categorical dummies in respective collectives:
reg read pc_class tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 clsize pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50 pedu_uni pedu_post pedu_upper pedu_lower pemp_full pemp_less pemp_not hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k speakhome_sometimes speakhome_never kinderg_att, robust
*par_edu
test pedu_uni pedu_post pedu_upper pedu_lower
*RESULT: Rejecting null hypothesis of collective insignificans, p>F = 0.0000
*
*par_emp
test pemp_full pemp_less pemp_not
*RESULT: Rejecting null hypothesis of collective insignificans, p>F = 0.0000
*income
test hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k
*RESULT: Rejecting null hypothesis of collective insignificans, p>F = 0.0000
*speak_testlang_home
test speakhome_sometimes speakhome_never
*RESULT: Rejecting null hypothesis of collective insignificans, p>F = 0.0000
*NOTE:
* R squared has seen a large significant increase with these added variables
********************************************************************************
*AID FOR REPORTING ESTIMATION RESULTS OF THE 6 MODELS IN ONE TABLE
********************************************************************************
*Using the added STATA toolkit estout for this purpose
eststo: reg read pc_class
eststo: reg read pc_class teacher_exp
eststo: reg read pc_class teacher_exp tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60, robust
eststo: reg read pc_class tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 clsize, robust
eststo: reg read pc_class clsize tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50, robust
eststo: reg read pc_class tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 clsize pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50 pedu_uni pedu_post pedu_upper pedu_lower pemp_full pemp_less pemp_not hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k speakhome_sometimes speakhome_never kinderg_att, robust
*esttab using ModellResultater.rtf, r2 se
*Needs a good deal of formatting and alterations, but provides a decent start 
********************************************************************************
*F-test of all variable (groups) in modell (6):
reg read pc_class tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60 clsize pdisad_11_25 pdisad_26_50 pdisad_o50 pabr_11_25 pabr_26_50 pabr_o50 pedu_uni pedu_post pedu_upper pedu_lower pemp_full pemp_less pemp_not hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k speakhome_sometimes speakhome_never kinderg_att, robust
test pc_class
test tage_25_29 tage_30_39 tage_40_49 tage_50_59 tage_o60
test clsize
test pdisad_11_25 pdisad_26_50 pdisad_o50
test pabr_11_25 pabr_26_50 pabr_o50
test pedu_uni pedu_post pedu_upper pedu_lower
test pemp_full pemp_less pemp_not
test hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k
test speakhome_sometimes speakhome_never
test kinderg_att
********************************************************************************
*Continuation modell 7
reg read pc_class clsize pdisad_11_25 pdisad_26_50 pdisad_o50 pedu_uni pedu_post pedu_upper pedu_lower pemp_full pemp_less pemp_not hinc_20k29 hinc_30k39 hinc_40k49 hinc_50k59 hinc_o60k speakhome_sometimes speakhome_never, robust
